@@ -132,21 +132,21 @@ pub fn get_last_key_pressed() -> Option<KeyCode> {
     context.keys_pressed.iter().next().cloned()
 }
 
-/// Detect if the key is being pressed
+/// Detect if the button is being pressed
 pub fn is_mouse_button_down(btn: MouseButton) -> bool {
     let context = get_context();
 
     context.mouse_down.contains(&btn)
 }
 
-/// Detect if the key has been pressed once
+/// Detect if the button has been pressed once
 pub fn is_mouse_button_pressed(btn: MouseButton) -> bool {
     let context = get_context();
 
     context.mouse_pressed.contains(&btn)
 }
 
-/// Detect if the key has been released this frame
+/// Detect if the button has been released this frame
 pub fn is_mouse_button_released(btn: MouseButton) -> bool {
     let context = get_context();
 
@@ -159,6 +159,16 @@ fn convert_to_local(pixel_pos: Vec2) -> Vec2 {
         - Vec2::new(1.0, 1.0)
 }
 
+/// Prevents quit
+pub fn prevent_quit() {
+    get_context().prevent_quit_event = true;
+}
+
+/// Detect if quit has been requested
+pub fn is_quit_requested() -> bool {
+    get_context().quit_requested
+}
+
 /// Functions for advanced input processing.
 ///
 /// Functions in this module should be used by external tools that uses miniquad system, like different UI libraries. User shouldn't use this function.
