@@ -123,11 +123,14 @@ pub mod rand {
     pub use quad_rand::*;
 }
 
-#[cfg(feature = "log-impl")]
-/// Logging macros, available with "log-impl" feature.
+#[cfg(not(feature = "log-rs"))]
+/// Logging macros, available with miniquad "log-impl" feature.
 pub mod logging {
     pub use miniquad::{debug, error, info, warn};
 }
+#[cfg(feature = "log-rs")]
+// Use logging facade
+pub use ::log as logging;
 pub use miniquad;
 
 use crate::{
@@ -158,6 +161,9 @@ struct Context {
     mouse_position: Vec2,
     mouse_wheel: Vec2,
 
+    prevent_quit_event: bool,
+    quit_requested: bool,
+
     cursor_grabbed: bool,
 
     input_events: Vec<Vec<MiniquadInputEvent>>,
@@ -273,6 +279,9 @@ impl Context {
             mouse_position: vec2(0., 0.),
             mouse_wheel: vec2(0., 0.),
 
+            prevent_quit_event: false,
+            quit_requested: false,
+
             cursor_grabbed: false,
 
             input_events: Vec::new(),
@@ -337,6 +346,8 @@ impl Context {
         self.mouse_pressed.clear();
         self.mouse_released.clear();
 
+        self.quit_requested = false;
+
         // remove all touches that were Ended or Cancelled
         self.touches.retain(|_, touch| {
             touch.phase != input::TouchPhase::Ended && touch.phase != input::TouchPhase::Cancelled
@@ -630,6 +641,14 @@ impl EventHandlerFree for Stage {
         #[cfg(target_os = "android")]
         get_context().audio_context.pause();
     }
+
+    fn quit_requested_event(&mut self) {
+        let context = get_context();
+        if context.prevent_quit_event {
+            context.quad_context.cancel_quit();
+            context.quit_requested = true;
+        }
+    }
 }
 
 /// Not meant to be used directly, only from the macro.
