@@ -61,11 +61,11 @@ impl Image {
     /// ```
     pub fn from_file_with_format(bytes: &[u8], format: Option<image::ImageFormat>) -> Image {
         let img = if let Some(fmt) = format {
-            image::load_from_memory_with_format(&bytes, fmt)
+            image::load_from_memory_with_format(bytes, fmt)
                 .unwrap_or_else(|e| panic!("{}", e))
                 .to_rgba8()
         } else {
-            image::load_from_memory(&bytes)
+            image::load_from_memory(bytes)
                 .unwrap_or_else(|e| panic!("{}", e))
                 .to_rgba8()
         };
@@ -480,11 +480,11 @@ impl Texture2D {
         format: Option<image::ImageFormat>,
     ) -> Texture2D {
         let img = if let Some(fmt) = format {
-            image::load_from_memory_with_format(&bytes, fmt)
+            image::load_from_memory_with_format(bytes, fmt)
                 .unwrap_or_else(|e| panic!("{}", e))
                 .to_rgba8()
         } else {
-            image::load_from_memory(&bytes)
+            image::load_from_memory(bytes)
                 .unwrap_or_else(|e| panic!("{}", e))
                 .to_rgba8()
         };
